akhdefo_functions.stackprep — Akhdefo software documentation

# akhdefo_functions.stackprep

akhdefo_functions.stackprep(path_to_flowxnFolder='', path_toFlowynFolder='', dem='', print_list=False, start_date='YYYYMMDD', end_date='YYYYMMDD', output_stackedFolder='', VEL_scale=('month', 'year'), xres=3.125, yres=3.125, Velocity_shapeFile=False, Resampling=True)

  This program collects velocity candiate points for time-series analysis.

  ## Parameters

  path_to_flowxnFolderstr

    path to folder include east-west velocity files

  path_toFlowynFolderstr

    path to folder include north-south velocity files

  demstr

    path to digital elevation model file will be used to geocode the products

  print_listbool

    print list of temporal proceesed dates default is False

  start_datestr

    “YYYYMMDD”

  end_datestr

    “YYYYMMDD”

  output_stackedFolder : str

  VEL_scalestr

    “month” or “year”) at this stage you can ignore this option; will be removed from future versions

  xres : float

  yres : float

  Velocity_shapeFile: bool

  > set to True if need to generate points for temporal deformation analysis

  Resampling : bool

  > if True reduce number of measurement points but faster processing

  ## Returns

  ESRI Shapefile

    This file include candiate velocity points for timeseries analysis